==> servlet-tck-4.0.0.zip: servlet-tck/src/com/sun/ts/tests/servlet/spec/srlistener/SRListener.java <==
/*
 * Copyright (c) 2009, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id:$
 */
package com.sun.ts.tests.servlet.spec.srlistener;

import javax.servlet.ServletRequestEvent;
import javax.servlet.ServletRequestListener;
import java.util.ArrayList;

public final class SRListener implements ServletRequestListener {

  // Public Methods
  public void requestDestroyed(ServletRequestEvent event) {
    ArrayList al = null;
    al = (ArrayList) event.getServletContext().getAttribute("arraylist");
    if (al != null) {
      System.out.println("in requestDestroyed method of listener");
      al.add("in requestDestroyed method of listener");
      event.getServletContext().setAttribute("arraylist", al);
    }
  }

  public void requestInitialized(ServletRequestEvent event) {
    ArrayList al = null;
    al = (ArrayList) event.getServletContext().getAttribute("arraylist");
    if (al == null) {
      al = new ArrayList();
    }
    System.out.println("in requestInitialized method of listener");
    al.add("in requestInitialized method of listener");
    event.getServletContext().setAttribute("arraylist", al);
  }
}

==> servlet-tck-5.0.0.zip: servlet-tck/src/com/sun/ts/tests/servlet/spec/srlistener/SRListener.java <==
/*
 * Copyright (c) 2009, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id:$
 */
package com.sun.ts.tests.servlet.spec.srlistener;

import jakarta.servlet.ServletRequestEvent;
import jakarta.servlet.ServletRequestListener;
import java.util.ArrayList;

public final class SRListener implements ServletRequestListener {

  // Public Methods
  public void requestDestroyed(ServletRequestEvent event) {
    ArrayList al = null;
    al = (ArrayList) event.getServletContext().getAttribute("arraylist");
    if (al != null) {
      System.out.println("in requestDestroyed method of listener");
      al.add("in requestDestroyed method of listener");
      event.getServletContext().setAttribute("arraylist", al);
    }
  }

  public void requestInitialized(ServletRequestEvent event) {
    ArrayList al = null;
    al = (ArrayList) event.getServletContext().getAttribute("arraylist");
    if (al == null) {
      al = new ArrayList();
    }
    System.out.println("in requestInitialized method of listener");
    al.add("in requestInitialized method of listener");
    event.getServletContext().setAttribute("arraylist", al);
  }
}
